@@ -3,8 +3,10 @@ from unittest import TestCase, TestLoader, TextTestRunner, skipIf
 from warnings import warn
 import sys
 from os.path import join
+from os import name
 from json import load
 from contextlib import contextmanager
+import pickle
 import re
 
 from six import iteritems, StringIO
@@ -21,6 +23,10 @@ try:
     import pandas
 except:
     pandas = None
+try:
+    import tabulate
+except:
+    tabulate = None
 
 if __name__ == "__main__":
     sys.path.insert(0, "../..")
@@ -107,27 +113,37 @@ class TestCobraFluxAnalysis(TestCase):
                 optimize_minimal_flux(model, solver=solver)
             model.reactions.ATPM.lower_bound = atpm
 
-    def test_single_gene_deletion(self):
+    def test_single_gene_deletion_fba(self):
         cobra_model = create_test_model("textbook")
         # expected knockouts for textbook model
-        growth_dict = {"fba": {"b0008": 0.87, "b0114": 0.80, "b0116": 0.78,
-                               "b2276": 0.21, "b1779": 0.00},
-                       "moma": {"b0008": 0.87, "b0114": 0.71, "b0116": 0.56,
-                                "b2276": 0.11, "b1779": 0.00},
-                       }
+        growth_dict = {"b0008": 0.87, "b0114": 0.80, "b0116": 0.78,
+                       "b2276": 0.21, "b1779": 0.00}
 
-        # MOMA requires cplex or gurobi
+        rates, statuses = single_gene_deletion(cobra_model,
+                                               gene_list=growth_dict.keys(),
+                                               method="fba")
+        for gene, expected_value in iteritems(growth_dict):
+            self.assertEqual(statuses[gene], 'optimal')
+            self.assertAlmostEqual(rates[gene], expected_value, places=2)
+
+    def test_single_gene_deletion_moma(self):
+        # MOMA requires a QP solver
         try:
             get_solver_name(qp=True)
         except:
-            growth_dict.pop('moma')
-        for method, expected in growth_dict.items():
-            rates, statuses = single_gene_deletion(cobra_model,
-                                                   gene_list=expected.keys(),
-                                                   method=method)
-            for gene, expected_value in iteritems(expected):
-                self.assertEqual(statuses[gene], 'optimal')
-                self.assertAlmostEqual(rates[gene], expected_value, places=2)
+            self.skipTest("no qp support")
+
+        cobra_model = create_test_model("textbook")
+        # expected knockouts for textbook model
+        growth_dict = {"b0008": 0.87, "b0114": 0.71, "b0116": 0.56,
+                       "b2276": 0.11, "b1779": 0.00}
+
+        rates, statuses = single_gene_deletion(cobra_model,
+                                               gene_list=growth_dict.keys(),
+                                               method="moma")
+        for gene, expected_value in iteritems(growth_dict):
+            self.assertEqual(statuses[gene], 'optimal')
+            self.assertAlmostEqual(rates[gene], expected_value, places=2)
 
     def test_single_reaction_deletion(self):
         cobra_model = create_test_model("textbook")
@@ -167,7 +183,8 @@ class TestCobraFluxAnalysis(TestCase):
             [0.858, 0.863, 0.814, 0.000, 0.874, 0.874, 0.874, 0.874],
             [0.858, 0.863, 0.814, 0.000, 0.874, 0.874, 0.874, 0.874],
             [0.858, 0.863, 0.814, 0.000, 0.874, 0.874, 0.874, 0.874]]
-        solution = double_gene_deletion(cobra_model, gene_list1=genes)
+        opts = {"number_of_processes": 1} if name == "nt" else {}
+        solution = double_gene_deletion(cobra_model, gene_list1=genes, **opts)
         self.assertEqual(solution["x"], genes)
         self.assertEqual(solution["y"], genes)
         self.compare_matrices(growth_list, solution["data"])
@@ -323,27 +340,38 @@ class TestCobraFluxAnalysis(TestCase):
         for item in desired_entries:
             self.assertIn(re.sub('\s', '', item), output_set)
 
-    @skipIf(pandas is None, "summary methods require pandas")
+    @skipIf((pandas is None) or (tabulate is None),
+            "summary methods require pandas and tabulate")
     def test_summary_methods(self):
 
         # Test model summary methods
         model = create_test_model("textbook")
-        model.optimize()
+        with self.assertRaises(Exception):
+            model.summary()
+
+        # Load model solution
+        with open(join(data_directory, "textbook_solution.pickle"),
+                  "rb") as infile:
+            model.solution = pickle.load(infile)
+
         desired_entries = [
-            u'glc__D_e     -9.76 \u00B1 0.24'
-            u'co2_e       21.81 \u00B1 2.86',
-            u'nh4_e        -4.84 \u00B1 0.32'
-            u'h_e         19.51 \u00B1 2.86',
-            u'pi_e         -3.13 \u00B1 0.08'
-            u'for_e        2.86 \u00B1 2.86',
-            u'ac_e         0.95 \u00B1 0.95',
-            u'acald_e      0.64 \u00B1 0.64',
-            u'pyr_e        0.64 \u00B1 0.64',
-            u'etoh_e       0.55 \u00B1 0.55',
-            u'lac__D_e     0.54 \u00B1 0.54',
-            u'succ_e       0.42 \u00B1 0.42',
-            u'akg_e        0.36 \u00B1 0.36',
-            u'glu__L_e     0.32 \u00B1 0.32'
+            'idFluxRangeidFluxRangeBiomass_Ecol...0.874',
+            'o2_e       21.8   [19.9, 23.7]'
+            'h2o_e       29.2  [25, 30.7]',
+            'glc__D_e   10     [9.52, 10]'
+            'co2_e       22.8  [18.9, 24.7]',
+            'nh4_e       4.77  [4.53, 5.16]'
+            'h_e         17.5  [16.7, 22.4]',
+            'pi_e        3.21  [3.05, 3.21]'
+            'for_e        0    [0, 5.72]',
+            'ac_e         0    [0, 1.91]',
+            'pyr_e        0    [0, 1.27]',
+            'lac__D_e     0    [0, 1.07]',
+            'succ_e       0    [0, 0.837]',
+            'glu__L_e     0    [0, 0.636]',
+            'akg_e        0    [0, 0.715]',
+            'etoh_e       0    [0, 1.11]',
+            'acald_e      0    [0, 1.27]',
         ]
         for solver in solver_dict:
             with captured_output() as (out, err):
@@ -352,56 +380,57 @@ class TestCobraFluxAnalysis(TestCase):
 
         # test non-fva version (these should be fixed for textbook model
         desired_entries = [
-            "o2_e       -21.80",
-            "glc__D_e   -10.00",
-            "nh4_e       -4.77",
-            "pi_e        -3.21",
-            "h2o_e    29.18",
-            "co2_e    22.81",
-            "h_e      17.53",
-            "Biomass_Ecoli_core    0.874"
+            'o2_e      21.8',
+            'glc__D_e  10',
+            'nh4_e      4.77',
+            'pi_e       3.21',
+            'h2o_e  29.2',
+            'co2_e  22.8',
+            'h_e    17.5',
+            'Biomass_Ecol...  0.874',
         ]
         # Need to use a different method here because
         # there are multiple entries per line.
-        with captured_output() as (out, err):
-            model.summary()
-        s = out.getvalue()
-        for i in desired_entries:
-            self.assertIn(i, s)
+        for solver in solver_dict:
+            with captured_output() as (out, err):
+                model.summary()
+
+            s = out.getvalue()
+            for i in desired_entries:
+                self.assertIn(i, s)
 
         # Test metabolite summary methods
         desired_entries = [
-            'PRODUCING REACTIONS -- Ubiquinone-8',
-            '-----------------------------------',
-            '%      FLUX   RXN ID'
-            'REACTION',
-            '100.0%     44    CYTBD'
-            '2.0 h_c + 0.5 o2_c + q8h2_c --> h2o_c + 2.0 h_e +...',
-            'CONSUMING REACTIONS -- Ubiquinone-8',
-            '-----------------------------------',
-            '88.4%    -39   NADH16'
-            '4.0 h_c + nadh_c + q8_c --> 3.0 h_e + nad_c + q8h2_c',
-            '11.6%   -5.1    SUCDi'
-            'q8_c + succ_c --> fum_c + q8h2_c',
+            'PRODUCING REACTIONS -- Ubiquinone-8 (q8_c)',
+            '%       FLUX  RXN ID    REACTION',
+            '100%   43.6   CYTBD     '
+            '2.0 h_c + 0.5 o2_c + q8h2_c --> h2o_c + 2.0 h_e...',
+            'CONSUMING REACTIONS -- Ubiquinone-8 (q8_c)',
+            '%       FLUX  RXN ID    REACTION',
+            '88%    38.5   NADH16    '
+            '4.0 h_c + nadh_c + q8_c --> 3.0 h_e + nad_c + q...',
+            '12%     5.06  SUCDi     q8_c + succ_c --> fum_c + q8h2_c',
         ]
-        with captured_output() as (out, err):
-            model.metabolites.q8_c.summary()
-        self.check_entries(out, desired_entries)
+
+        for solver in solver_dict:
+            with captured_output() as (out, err):
+                model.metabolites.q8_c.summary()
+            self.check_entries(out, desired_entries)
 
         desired_entries = [
-            u'PRODUCING REACTIONS -- D-Fructose 1,6-bisphosphate',
-            u'--------------------------------------------------',
-            u'  %            FLUX   RXN ID'
-            u'REACTION',
-            u'100.0%  7.71 \u00B1 1.54      PFK'
-            u'atp_c + f6p_c --> adp_c + fdp_c + h_c',
-            u'CONSUMING REACTIONS -- D-Fructose 1,6-bisphosphate',
-            u'--------------------------------------------------',
-            u'  %            FLUX   RXN ID'
-            u'REACTION',
-            u'100.0%  7.54 \u00B1 1.37      FBA'
-            u'fdp_c <=> dhap_c + g3p_c',
+            'PRODUCING REACTIONS -- D-Fructose 1,6-bisphosphate (fdp_c)',
+            '----------------------------------------------------------',
+            '%       FLUX  RANGE         RXN ID    REACTION',
+            '100%    7.48  [6.17, 9.26]  PFK       '
+            'atp_c + f6p_c --> adp_c + fdp_c + h_c',
+            'CONSUMING REACTIONS -- D-Fructose 1,6-bisphosphate (fdp_c)',
+            '----------------------------------------------------------',
+            '%       FLUX  RANGE         RXN ID    REACTION',
+            '100%    7.48  [6.17, 8.92]  FBA       fdp_c <=> dhap_c + g3p_c',
+            '0%      0     [0, 1.72]     FBP       '
+            'fdp_c + h2o_c --> f6p_c + pi_c',
         ]
+
         for solver in solver_dict:
             with captured_output() as (out, err):
                 model.metabolites.fdp_c.summary(fva=0.99, solver=solver)
