@@ -289,7 +289,6 @@ class TestReactions(CobraTestCase):
         model = self.model
         reaction = model.reactions.get_by_id("PGI")
         old_gene = list(reaction.genes)[0]
-        old_gene_reaction_rule = reaction.gene_reaction_rule
         new_gene = model.genes.get_by_id("s0001")
         # add an existing 'gene' to the gpr
         reaction.gene_reaction_rule = 's0001'
@@ -357,6 +356,9 @@ class TestReactions(CobraTestCase):
         pgi = model.reactions.get_by_id("PGI")
         pgi.reaction = "g6p_c --> f6p_c"
         self.assertEqual(pgi.lower_bound, 0)
+        pgi.bounds = (0, 1000)
+        self.assertEqual(pgi.bounds, (0, 1000))
+        self.assertEqual(pgi.reversibility, False)
         pgi.reaction = "g6p_c <== f6p_c"
         self.assertEqual(pgi.upper_bound, 0)
         self.assertEqual(pgi.reaction.strip(), "g6p_c <-- f6p_c")
@@ -649,7 +651,7 @@ class TestCobraModel(CobraTestCase):
         contained in reactions after adding them to the model.
         """
         _model = self.model_class('test')
-        _model.add_reactions([x.copy() for x in self.model.reactions])
+        _model.add_reactions((x.copy() for x in self.model.reactions))
         _genes = []
         _metabolites = []
         for x in _model.reactions:
@@ -776,6 +778,21 @@ class TestCobraArrayModel(TestCobraModel):
         with self.assertRaises(TypeError):
             model.reactions[[True, False]]
 
+    def test_array_based_bounds_setting(self):
+        model = self.model
+        bounds = [0.0] * len(model.reactions)
+        model.lower_bounds = bounds
+        self.assertEqual(type(model.reactions[0].lower_bound), float)
+        self.assertAlmostEqual(model.reactions[0].lower_bound, 0.0)
+        model.upper_bounds[1] = 1234.0
+        self.assertAlmostEqual(model.reactions[1].upper_bound, 1234.0)
+        model.upper_bounds[9:11] = [100.0, 200.0]
+        self.assertAlmostEqual(model.reactions[9].upper_bound, 100.0)
+        self.assertAlmostEqual(model.reactions[10].upper_bound, 200.0)
+        model.upper_bounds[9:11] = 123.0
+        self.assertAlmostEqual(model.reactions[9].upper_bound, 123.0)
+        self.assertAlmostEqual(model.reactions[10].upper_bound, 123.0)
+
 
 # make a test suite to run all of the tests
 loader = TestLoader()
